@@ -9,36 +9,44 @@ from gitignore_parser import parse_gitignore
 
 
 end_terminators = {
-    '//style': '// inserted by copyright_tool',
-    '#style': '## inserted by copyright_tool'
+    'slash': '// inserted by copyright_tool',
+    'hash': '## inserted by copyright_tool'
 }
 
 language_support = {
-    'c': '//cstyle',
-    'cpp': '//cstyle',
-    'c++': '//cstyle',
-    'h': '//cstyle',
-    'hpp': '//cstyle',
-    'ts': '//cstyle',
-    'js': '//cstyle',
-    'tsx': '//cstyle',
-    'jsx': '//cstyle',
-    'py': '#style',
-    'sh': '#style',
-    'java': '//cstyle',
-    'tf': '#style',
+    'c': 'slash',
+    'cpp': 'slash',
+    'h': 'slash',
+    'hpp': 'slash',
+    'ts': 'slash',
+    'js': 'slash',
+    'tsx': 'slash',
+    'jsx': 'slash',
+    'py': 'hash',
+    'sh': 'hash',
+    'java': 'slash',
+    'tf': 'hash',
 }
 
-def get_copyright_files_map(path):
-  file_map = {}
-  for file_name in os.listdir(path):
-    if file_name.startswith('.copyright.'):
-      language = file_name.split('.')[2]
-      style = language_support.get(language)
-      if not style:
-        raise ValueError(f'Language {language} not supported')
-      file_map[language] = file_name
-  return file_map
+file_support = {
+  'Dockerfile': 'hash',
+  'Makefile': 'hash'
+}
+
+def get_copyright_file(root_path, file_path):
+  language = file_path.split('.')[-1]
+  base_file = os.path.basename(file_path).split('.')[0]
+  tpl_type = language_support.get(language)
+  if not tpl_type:
+    tpl_type = file_support.get(base_file)
+  if not tpl_type:
+    return None
+  copyright_file = f'{root_path}/.copyright.{tpl_type}.tpl'
+  if os.path.exists(copyright_file):
+    return copyright_file
+  else:
+    return None
+
 
 
 def get_all_files(path):
@@ -46,14 +54,12 @@ def get_all_files(path):
   matches = None
   if os.path.exists(copyright_ignore_path):
     matches = parse_gitignore(copyright_ignore_path)
-  copyright_file_map = get_copyright_files_map(path)
 
   def get_tracked_files(trees):
     paths = []
     for tree in trees:
       for blob in tree.blobs:
-        language = blob.abspath.split('.')[-1]
-        if not matches or not matches(blob.abspath) and copyright_file_map.get(language):
+        if not matches or not matches(blob.abspath) and get_copyright_file(path, blob.abspath):
           paths.append(blob.abspath)
       if tree.trees:
         paths.extend(get_tracked_files(tree.trees))
@@ -69,12 +75,14 @@ def main():
     sys.exit(1)
 
   path = sys.argv[1]
-  copyright_file_map = get_copyright_files_map(path)
   file_name: str
+
   for file_name in get_all_files(path):
     with open(file_name, 'r') as filed:
       language = file_name.split('.')[-1]
       end_terminator = end_terminators.get(language_support.get(language))
+      if not end_terminator:
+        end_terminator = end_terminators.get(file_support.get(os.path.basename(file_name).split('.')[0]))
 
       body_lines: List[str] = filed.readlines()
       if not body_lines:
@@ -96,7 +104,9 @@ def main():
       else:
         content_lines = body_lines[start_index:]
 
-    copyright_file = f"{path}/{copyright_file_map.get(language)}"
+    copyright_file = get_copyright_file(path, file_name)
+    if not copyright_file:
+        continue
 
     with open(copyright_file) as filed:
       copyright = filed.read().format(year = datetime.datetime.now().year)
